pub struct ContinuousSpace2D { /* private fields */ }Expand description
2D continuous space with spatial hashing.
Agents are tracked by position and indexed into a uniform grid for fast
neighbor queries. The grid cell size (spacing) determines the tradeoff
between query accuracy and move_agent_pos overhead.
Boundary modes
periodic = true- toroidal wrapping.periodic = false- bounded; out-of-bounds positions returnContinuousSpaceError::OutOfBounds.
Implementations
Sourceimpl ContinuousSpace2D
impl ContinuousSpace2D
Sourcepub fn new(
extent_x: f64,
extent_y: f64,
periodic: bool,
spacing: f64,
) -> Result<Self, ContinuousSpaceConfigError>
pub fn new( extent_x: f64, extent_y: f64, periodic: bool, spacing: f64, ) -> Result<Self, ContinuousSpaceConfigError>
Create a new 2D continuous space.
Arguments
extent_x,extent_y- space dimensions.periodic- whether boundaries wrap.spacing- cell side length for the spatial hash grid.
Sourcepub fn agent_position(&self, id: AgentId) -> Option<&ContinuousPos>
pub fn agent_position(&self, id: AgentId) -> Option<&ContinuousPos>
Look up the current position of an agent.
Sourcepub fn move_agent_pos(
&mut self,
id: AgentId,
new_pos: ContinuousPos,
) -> Result<ContinuousPos, ContinuousSpaceError>
pub fn move_agent_pos( &mut self, id: AgentId, new_pos: ContinuousPos, ) -> Result<ContinuousPos, ContinuousSpaceError>
Move an agent to a new position, updating the spatial hash.
Returns the (possibly normalized) final position, or an error if the position is out of bounds in a non-periodic space.
Sourcepub fn nearby_ids_euclidean(
&self,
pos: &ContinuousPos,
radius: f64,
) -> Vec<AgentId> ⓘ
pub fn nearby_ids_euclidean( &self, pos: &ContinuousPos, radius: f64, ) -> Vec<AgentId> ⓘ
Find all agent IDs within Euclidean distance radius of pos.
Respects periodic boundaries when enabled.