Graph-based discrete space.
GraphSpace represents a network where each node can hold agents.
Agents move along edges, and distance is measured in hops (BFS).
Supports both directed and undirected graphs with dynamic topology
(vertices and edges can be added/removed at runtime).
Mirrors Julia Agents.jl GraphSpace.
Structs
- Graph
Space - A graph-based discrete space mirroring Julia Agents.jl
GraphSpace.
Enums
- Graph
Space Error - Errors returned by graph space operations.
- Neighbor
Type - Neighbor search direction for directed graphs.
Type Aliases
- Graph
Pos - Position in a graph space - a node index (
0..num_vertices).